@@ -28,6 +28,7 @@ try:
 except ImportError:
     humanfriendly = None
 
+__version__ = "0.3"
 logging.basicConfig(level=logging.INFO, format="%(levelname)s: %(message)s")
 logger = logging.getLogger("docker-export")
 logging.getLogger("urllib3").setLevel(logging.WARNING)
@@ -203,6 +204,14 @@ class Image:
     def reference(self):
         return self.digest or self.tag
 
+    @property
+    def url(self):
+        domain = (
+            "hub.docker.com" if self.registry == "index.docker.io" else self.registry
+        )
+        prefix = "r/" if self.registry == "index.docker.io" else ""
+        return f"https://{domain}/{prefix}/{self.fullname}"
+
     @classmethod
     def parse(
         cls,
@@ -314,6 +323,17 @@ def get_manifests(image, auth):
             **{"Accept": "application/vnd.docker.distribution.manifest.list.v2+json"},
         ),
     )
+    if resp.status_code == 401:
+        raise IOError(
+            f"HTTP {resp.status_code}: {resp.reason} -- "
+            "This **may** indicate an incorrect image name/registry/repo/tag.\n"
+            f"Check {image.url}"
+        )
+    if resp.status_code == 404:
+        raise ValueError(
+            f"HTTP {resp.status_code}: {resp.reason} -- "
+            f"Image name is probably incorrect.\nCheck {image.url}"
+        )
     if resp.status_code != 200:
         raise IOError(f"HTTP {resp.status_code}: {resp.reason} -- {resp.text}")
 
@@ -595,10 +615,21 @@ def export_layers(
 
     # write image digest
     digest = manifest["config"]["digest"]
-    config = requests.get(
+    logger.debug(f"{digest=}")
+    resp = requests.get(
         f"https://{image.registry}/v2/{image.fullname}/blobs/{digest}",
         headers=auth.headers,
-    ).content
+    )
+    if resp.status_code == 404:
+        logger.error(
+            "Unsupported manifest schema/version: digest blob not found\n\n"
+            "###############\n"
+            "Use regctl instead https://github.com/regclient/regclient\n"
+            f"regctl image export {image} {target}\n"
+            "###############\n"
+        )
+    resp.raise_for_status()
+    config = resp.content
 
     new_manifest = [
         {
@@ -681,8 +712,16 @@ def main():
     parser = argparse.ArgumentParser(
         prog="docker-export",
         description="Docker Registry HTTP API V2 based Image extractor",
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+        epilog="""Examples:
+    docker-export --platform linux/arm64 kiwix/kiwix-tools:3.3.0 kiwix-tools.tar
+    docker-export alpine alpine.tar
+
+See https://docs.docker.com/desktop/multi-arch/ for platforms list""",
     )
 
+    parser.add_argument("-V", "--version", action="version", version=__version__)
+
     parser.add_argument(
         help="name of image to pull. Can optionnaly include registry, repository "
         "and tag or digest using this format: "
@@ -692,28 +731,28 @@ def main():
 
     parser.add_argument(
         help="path to write exported image to. If it doesn't end in .tar, "
-        "it is expected to be a folder to write the image into.",
+        "it is expected to be a folder to write the image into",
         dest="output",
     )
 
     parser.add_argument(
         "--registry",
-        help="registry to pull image from"
-        "Defaults to registry definition in {image} or `docker.io`.",
+        help="registry to pull image from. "
+        "Defaults to registry definition in {image} or `docker.io`",
         dest="registry",
     )
 
     parser.add_argument(
         "--repository",
         help="repository to pull image from. "
-        "Defaults to repository definition in {image} or `library`.",
+        "Defaults to repository definition in {image} or `library`",
         dest="repository",
     )
 
     parser.add_argument(
         "--tag",
         help="tag version of image to pull. "
-        "Defaults to tag definition in {image} or `latest`.",
+        "Defaults to tag definition in {image} or `latest`",
         dest="tag",
     )
 
@@ -723,8 +762,10 @@ def main():
 
     parser.add_argument(
         "--platform",
-        help="Platform to download image for",
-        default="linux/arm/v7",
+        help="Platform to download image for. "
+        f"Defaults to `{Platform.auto()}` (guessed). "
+        "Ex: linux/amd64, linux/arm/v6, linux/arm/v7, linux/arm64, windows/amd64",
+        default="auto",
         dest="platform",
     )
 
